"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Resizer = void 0;
class ImgProxy {
    constructor(url, host, render_options) {
        if (!url) {
            throw "Invalid url";
        }
        this.url = url;
        this.host = host;
        this.parsed = false;
        this.render_options = render_options;
        this.prepareUrl();
        this.checkReadyUrl();
    }
    prepareUrl() {
        const options = this.render_options ?? {};
        const optionKeys = ['watermark', 'w', 'h'];
        const builder = optionKeys.map(k => options?.[k] ? `/{${k}}` : '').join('');
        this.url = `${this.host}/Acbs8526SDKI/resizing_type:fill${builder}/plain/${this.url}`;
    }
    checkReadyUrl() {
        if (!this.url.endsWith("@webp")) {
            this.url = this.url + "@webp";
        }
    }
    getParsedUrl() {
        if (this.readyUrl)
            return this.readyUrl;
        if (this.parsed)
            return this.url;
        const optionEntries = Object.entries(this.render_options ?? {});
        if (optionEntries.length > 0) {
            this.url += "?";
            optionEntries.forEach(([optionKey, value]) => {
                const func = this?.[optionKey];
                if (value && typeof func === 'function') {
                    this.url = func(value, this.url);
                }
            });
        }
        this.parsed = true;
        return this.url;
    }
    w(val, url) {
        const to = val ? "/width:" + val : "";
        return url.replace("/{w}", to);
    }
    h(val, url) {
        const to = val ? "/height:" + val : "";
        return url.replace("/{h}", to);
    }
    watermark(val, url) {
        const to = val ? "/watermark:" + val : "";
        return url.replace("/{watermark}", to);
    }
}
class Resizer {
    constructor(service_host) {
        this.service_host = service_host;
    }
    resize(image_url, render_options) {
        const alreadyResized = image_url.includes(this.service_host);
        if (alreadyResized) {
            return image_url;
        }
        const processor = new ImgProxy(image_url, this.service_host, render_options ?? {});
        return processor.getParsedUrl();
    }
}
exports.Resizer = Resizer;
